==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QHoverEvent_shell.h <==
#ifndef QHOVEREVENT_SHELL_H
#define QHOVEREVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QHoverEvent_shell : public QHoverEvent, public QtJambiShellInterface
{
public:
    QHoverEvent_shell(QEvent::Type type0, const QPointF& scenePos1, const QPointF& globalPos2, const QPointF& oldPos3, Qt::KeyboardModifiers modifiers4 = Qt::NoModifier, const QPointingDevice* device5 = QPointingDevice::primaryPointingDevice());
    QHoverEvent_shell(QEvent::Type type0, const QPointF& pos1, const QPointF& oldPos2, Qt::KeyboardModifiers modifiers3 = Qt::NoModifier, const QPointingDevice* device4 = QPointingDevice::primaryPointingDevice());
    QHoverEvent_shell(const QHoverEvent& arg__1);
    ~QHoverEvent_shell() override;

    QHoverEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHoverEvent_access : public QHoverEvent
{
    void __qt_assign_cref_QHoverEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QHOVEREVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QHoverEvent_shell.h <==
#ifndef QHOVEREVENT_SHELL_H
#define QHOVEREVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QHoverEvent_shell : public QHoverEvent, public QtJambiShellInterface
{
public:
    QHoverEvent_shell(QEvent::Type type0, const QPointF& scenePos1, const QPointF& globalPos2, const QPointF& oldPos3, Qt::KeyboardModifiers modifiers4 = Qt::NoModifier, const QPointingDevice* device5 = QPointingDevice::primaryPointingDevice());
    QHoverEvent_shell(QEvent::Type type0, const QPointF& pos1, const QPointF& oldPos2, Qt::KeyboardModifiers modifiers3 = Qt::NoModifier, const QPointingDevice* device4 = QPointingDevice::primaryPointingDevice());
    QHoverEvent_shell(const QHoverEvent& arg__1);
    ~QHoverEvent_shell() override;

    QHoverEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHoverEvent_access : public QHoverEvent
{
    void __qt_assign_cref_QHoverEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QHOVEREVENT_SHELL_H
